==> imwiki-7.5.27.tar.gz: imwiki-7.5.27/imLib/Revision.py <==
# -*- coding: utf8 -*-
import os
import fnmatch
import difflib
import cgi

import Repository
import utils
import Page
import Permission 
import Category

from WikiException import WikiException
class NotExistRevision(WikiException): pass

def getRevTimeStampList(categoryPath, pageName):
		fnameList = os.listdir(os.path.join(Repository.getBackupRepository(), utils.encode(categoryPath)))
		fnameList = fnmatch.filter(fnameList, utils.encode(pageName)+'.*')
		timeStampList = map(lambda fname: fname[-10:], fnameList)
		timeStampList.sort()
		return timeStampList

def getLastTimeStamp(categoryPath, pageName):
	timeStampList = getRevTimeStampList(categoryPath, pageName)
	if timeStampList:
		return int(timeStampList[-1])
	return None

class Revision(Permission.PermissionChecker):
	def __init__(self, category, pageName, timeStamp):
		self.pageName = pageName
		self.category = category
		self.encPageName = utils.encode(pageName)
		try:
			self.timeStamp = int(timeStamp)
		except ValueError:
			raise NotExistRevision
		self.filePath = os.path.join(Repository.getBackupRepository(), utils.encode(category.categoryPath), self.encPageName+'.'+str(self.timeStamp))
		if not self.pageName or not os.path.exists(self.filePath):
			raise NotExistRevision
		self.load()

	def load(self):
		fp = file(self.filePath, 'rb')
		s = fp.readline().strip()
		self.revPerms = Permission.Permission(s)
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self.loadPerms()
	def getGroup(self):
		return self.category.group
	def loadPerms(self):
		page = Page.getPage(self.category.categoryPath, self.pageName)
		if page:
			self.perms = page.perms
			return
		timeStamp = getLastTimeStamp(self.category.categoryPath, self.pageName)
		if timeStamp and int(timeStamp) == self.timeStamp:
			self.perms = self.revPerms
			return
		self.perms = Revision(self.category, self.pageName, timeStamp).revPerms

	def toRawText(self):
		teul = 'Tags : %s\n%s\n%s'
		return teul % (self.tags, '='*(len(self.tags) + 7), self.rawText)

	def diff(self, other):
		ret = []
		old = cgi.escape(self.rawText)
		new = cgi.escape(other.rawText)
		L = list(difflib.ndiff(old.splitlines(), new.splitlines()))
		ret = [] 
		for line in L:
			if line[0] == '+':
				ret.append('<span class="diffIns"><ins>%s</ins></span>' % line[2:])
			elif line[0] == '-':
				ret.append('<span class="diffDel"><del>%s</del></span>' % line[2:])
			elif line[0] == ' ':
				ret.append('%s' % line[2:])
		
		return '\n'.join(ret)

==> imwiki-7.6.16.tar.gz: imwiki-7.6.16/imLib/Revision.py <==
# -*- coding: utf8 -*-
import os
import fnmatch
import difflib
import cgi

import Repository
import utils
import Page
import Permission 
import Category

from WikiException import WikiException
class NotExistRevision(WikiException): pass

def getRevTimeStampList(categoryPath, pageName):
		fnameList = os.listdir(os.path.join(Repository.getPageBackupRepository(), utils.encode(categoryPath)))
		fnameList = fnmatch.filter(fnameList, utils.encode(pageName)+'.*')
		timeStampList = map(lambda fname: fname[-10:], fnameList)
		timeStampList.sort()
		return timeStampList

def getLastTimeStamp(categoryPath, pageName):
	timeStampList = getRevTimeStampList(categoryPath, pageName)
	if timeStampList:
		return int(timeStampList[-1])
	return None

class Revision(Permission.PermissionChecker):
	def __init__(self, category, pageName, timeStamp):
		self.pageName = pageName
		self.category = category
		self.encPageName = utils.encode(pageName)
		try:
			self.timeStamp = int(timeStamp)
		except ValueError:
			raise NotExistRevision
		self.filePath = os.path.join(Repository.getPageBackupRepository(), utils.encode(category.categoryPath), self.encPageName+'.'+str(self.timeStamp))
		if not self.pageName or not os.path.exists(self.filePath):
			raise NotExistRevision
		self.load()

	def load(self):
		fp = file(self.filePath, 'rb')
		s = fp.readline().strip()
		self.revPerms = Permission.Permission(s)
		self.tags = fp.readline().strip()
		self.rawText = fp.read()
		fp.close()
		self.loadPerms()
	def getGroup(self):
		return self.category.getGroup()
	def loadPerms(self):
		page = Page.getPage(self.category.categoryPath, self.pageName)
		if page:
			self.perms = page.perms
			return
		timeStamp = getLastTimeStamp(self.category.categoryPath, self.pageName)
		if timeStamp and int(timeStamp) == self.timeStamp:
			self.perms = self.revPerms
			return
		self.perms = Revision(self.category, self.pageName, timeStamp).revPerms

	def toRawText(self):
		teul = 'Tags : %s\n%s\n%s'
		return teul % (self.tags, '='*(len(self.tags) + 7), self.rawText)

	def diff(self, other):
		ret = []
		old = cgi.escape(self.rawText)
		new = cgi.escape(other.rawText)
		L = list(difflib.ndiff(old.splitlines(), new.splitlines()))
		ret = [] 
		for line in L:
			if line[0] == '+':
				ret.append('<span class="diffIns"><ins>%s</ins></span>' % line[2:])
			elif line[0] == '-':
				ret.append('<span class="diffDel"><del>%s</del></span>' % line[2:])
			elif line[0] == ' ':
				ret.append('%s' % line[2:])
		
		return '\n'.join(ret)
